@@ -198,7 +198,6 @@ class DiocoreHTMLField(TextField):
         }
     
         defaults = {
-            'widget': TinyMCE(mce_attrs=mce_default_attrs),
             'form_class': PoSafeTextField,
         }
         
@@ -209,9 +208,29 @@ class DiocoreHTMLField(TextField):
             defaults['max_length'] = self.max_length
             
         defaults.update(kwargs)
+        defaults['widget'] = TinyMCE(mce_attrs=mce_default_attrs)
+        
         return super(DiocoreHTMLField, self).formfield(**defaults)
 
 
+class CSSField(DiocoreHTMLField):
+    """
+    A field adds a *style* property when serialized by easymode.
+    
+    .. code-block:: xml
+    
+        <field type="CharField" name="title" style="large,at-left">Hi</field>
+        
+        
+    """
+    def __init__(self, *args, **kwargs):
+        self.styles = kwargs.pop('styles', None)
+        self.mce_width = kwargs.pop('width', 340)
+        self.mce_height = kwargs.pop('height', 160)
+        self.buttons = kwargs.pop('buttons', "bullist,numlist,|,undo,redo,|,link,unlink,|,code,|,cleanup,removeformat,code")
+
+        TextField.__init__(self, *args, **kwargs)
+    
 class DiocoreTextField(TextField):
     """
     This textfield stores a font as well.
